# OrganisationOwnerConfig

Configuration that an organisation owner has under their control. This configuration is used to handle various behaviors of an organisation and how is is used in the system as a whole. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**disable_user_requests** | **bool** | When true this property removes the visibility that all users in the organisation can see and request all published resources and applications in the users profile (https://profile.&lt;org subdomain&gt;).  By default, this property is false.  | [optional]  if omitted the server will use the default value of False
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


